package com.sun.media.sound;

import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.AudioInputStream;
import javax.sound.sampled.AudioFormat;

public final class Toolkit
{
    private Toolkit() {
    }
    
    static void getUnsigned8(byte[] array, int i, int n) {
        int n2;
        for (; i < i + n; ++i) {
            n2 = i;
            array[n2] += 128;
        }
    }
    
    static void getByteSwapped(byte[] array, int i, int n) {
        int n2;
        for (; i < i + n; i += 2) {
            n2 = array[i];
            array[i] = array[i + 1];
            array[i + 1] = n2;
        }
    }
    
    static float linearToDB(float n) {
        return (float)(Math.log(((double)n == 0.0) ? 1.0E-4 : ((double)n)) / Math.log(10.0) * 20.0);
    }
    
    static float dBToLinear(float n) {
        return (float)Math.pow(10.0, (double)n / 20.0);
    }
    
    static long align(long n, int n2) {
        if (n2 <= 1) {
            return n;
        }
        return n - n % (long)n2;
    }
    
    static int align(int n, int n2) {
        if (n2 <= 1) {
            return n;
        }
        return n - n % n2;
    }
    
    static long millis2bytes(AudioFormat audioFormat, long n) {
        return align((long)((float)n * audioFormat.getFrameRate() / 1000.0f * (float)audioFormat.getFrameSize()), audioFormat.getFrameSize());
    }
    
    static long bytes2millis(AudioFormat audioFormat, long n) {
        return (long)((float)n / audioFormat.getFrameRate() * 1000.0f / (float)audioFormat.getFrameSize());
    }
    
    static long micros2bytes(AudioFormat audioFormat, long n) {
        return align((long)((float)n * audioFormat.getFrameRate() / 1000000.0f * (float)audioFormat.getFrameSize()), audioFormat.getFrameSize());
    }
    
    static long bytes2micros(AudioFormat audioFormat, long n) {
        return (long)((float)n / audioFormat.getFrameRate() * 1000000.0f / (float)audioFormat.getFrameSize());
    }
    
    static long micros2frames(AudioFormat audioFormat, long n) {
        return (long)((float)n * audioFormat.getFrameRate() / 1000000.0f);
    }
    
    static long frames2micros(AudioFormat audioFormat, long n) {
        return (long)((double)n / (double)audioFormat.getFrameRate() * 1000000.0);
    }
    
    static void isFullySpecifiedAudioFormat(AudioFormat audioFormat) {
        if (audioFormat.getFrameSize() <= 0) {
            throw new IllegalArgumentException("invalid frame size: " + ((audioFormat.getFrameSize() == -1) ? "NOT_SPECIFIED" : String.valueOf(audioFormat.getFrameSize())));
        }
        if (!audioFormat.getEncoding().equals(AudioFormat.Encoding.PCM_SIGNED) && !audioFormat.getEncoding().equals(AudioFormat.Encoding.PCM_UNSIGNED) && !audioFormat.getEncoding().equals(AudioFormat.Encoding.ULAW) && !audioFormat.getEncoding().equals(AudioFormat.Encoding.ALAW)) {
            return;
        }
        if (audioFormat.getFrameRate() <= 0.0f) {
            throw new IllegalArgumentException("invalid frame rate: " + ((audioFormat.getFrameRate() == -1.0f) ? "NOT_SPECIFIED" : String.valueOf(audioFormat.getFrameRate())));
        }
        if (audioFormat.getSampleRate() <= 0.0f) {
            throw new IllegalArgumentException("invalid sample rate: " + ((audioFormat.getSampleRate() == -1.0f) ? "NOT_SPECIFIED" : String.valueOf(audioFormat.getSampleRate())));
        }
        if (audioFormat.getSampleSizeInBits() <= 0) {
            throw new IllegalArgumentException("invalid sample size in bits: " + ((audioFormat.getSampleSizeInBits() == -1) ? "NOT_SPECIFIED" : String.valueOf(audioFormat.getSampleSizeInBits())));
        }
        if (audioFormat.getChannels() <= 0) {
            throw new IllegalArgumentException("invalid number of channels: " + ((audioFormat.getChannels() == -1) ? "NOT_SPECIFIED" : String.valueOf(audioFormat.getChannels())));
        }
        return;
    }
    
    static boolean isFullySpecifiedPCMFormat(AudioFormat audioFormat) {
        return (audioFormat.getEncoding().equals(AudioFormat.Encoding.PCM_SIGNED) || audioFormat.getEncoding().equals(AudioFormat.Encoding.PCM_UNSIGNED)) && audioFormat.getFrameRate() > 0.0f && audioFormat.getSampleRate() > 0.0f && audioFormat.getSampleSizeInBits() > 0 && audioFormat.getFrameSize() > 0 && audioFormat.getChannels() > 0;
    }
    
    public static AudioInputStream getPCMConvertedAudioInputStream(AudioInputStream audioInputStream) {
        AudioFormat format = audioInputStream.getFormat();
        if (!format.getEncoding().equals(AudioFormat.Encoding.PCM_SIGNED) && !format.getEncoding().equals(AudioFormat.Encoding.PCM_UNSIGNED)) {
            try {
                audioInputStream = AudioSystem.getAudioInputStream(new AudioFormat(AudioFormat.Encoding.PCM_SIGNED, format.getSampleRate(), 16, format.getChannels(), format.getChannels() * 2, format.getSampleRate(), Platform.isBigEndian()), audioInputStream);
            }
            catch (Exception ex) {
                audioInputStream = null;
            }
        }
        return audioInputStream;
    }
}
